package Sophos::Product::Config;

use strict;
use warnings;

use PureMessage::Config qw(expand_filename);
use ActiveState::Config qw(:path);
use PureMessage::Version qw($PREFIX);
use base qw(Exporter);
our @EXPORT_OK = qw(%config %product_config);

my $CONFIG_FILE = expand_filename('etc/product.conf');
our %config;
our $object;

our $product_config; # alias that doesn't clash with other %configs
*product_config =\%config;

sub refresh() {
    $object = ActiveState::Config->new(strict => 1, allow_includes => 1);
    Sophos::Product::Config->validate($object);
    $object->parse_file($CONFIG_FILE);
    %config = $object->as_hash;
}

refresh();

=item edit()

 Will open this config as a writable  ActiveState::Config object
 and return it. This can die when configuration file has invalid
 syntax.

=cut

sub edit {
    my $p = ActiveState::Config->new(strict => 1, allow_includes => 1);
    Sophos::Product::Config->validate($p);
    $p->parse_file($CONFIG_FILE, writable => 1);
    return $p;
}

sub validate {
    my ($pkg, $p) = @_;

    # Define validation rules and default values.
    my %conf = (
            'product.awk'              => ['#str', 'awk'],
            'product.egrep'            => ['#str', "$PREFIX/bin/pmx-grep -i -e"],
            'product.egrep_offset'     => ['#str', "$PREFIX/bin/pmx-grep -1 -b -e"], 
            'product.gunzip'           => ['#str', "$PREFIX/bin/pmx-gzip -d"],
            'product.gunzip_to_stdout' => ['#str', "$PREFIX/bin/pmx-gzip -d -s"],
            'product.gunzip_info'      => ['#str', "$PREFIX/bin/pmx-gzip -l"],
            'product.gzip'             => ['#str', "$PREFIX/bin/pmx-gzip -c"],
            'product.head_n'           => ['#str', "$PREFIX/bin/pmx-head -n"],
            'product.join'             => ['#str', "$PREFIX/bin/pmx-join -o"],
            'product.mkfifo'           => ['#str', 'mkfifo'],
            'product.sort'             => ['#str', "$PREFIX/bin/pmx-sort"],
            'product.tail_n'           => ['#str', "$PREFIX/bin/pmx-tail -n"],
            'product.maillog_plain'    => ['#str', "$PREFIX/bin/pmx-maillog"],
            'product.slicer'           => ['#str', "$PREFIX/bin/slicer"],
    );

    # Add our validation rules to the parser.
    foreach my $key (keys %conf)
    {
        my ($type, $def) = @{$conf{$key}};
        $p->typedecl( $key, $type ) if (defined $type);
        $p->default( $key, $def )   if (defined $def);
    }
}

1;

